==> sword_1.5.3.orig.tar.gz: sword-1.5.3.orig/apps/windoze/CBuilder5/InstallMgr/RemoteMntFrm.h <==
//---------------------------------------------------------------------------
#ifndef RemoteMntFrmH
#define RemoteMntFrmH
//---------------------------------------------------------------------------
#include <Classes.hpp>
#include <Controls.hpp>
#include <StdCtrls.hpp>
#include <Forms.hpp>
#include <Buttons.hpp>
#include <ExtCtrls.hpp>
#include <swconfig.h>
//---------------------------------------------------------------------------
class TRemoteMntForm : public TForm
{
__published:	// IDE-managed Components
	TPanel *Panel1;
	TPanel *Panel2;
	TPanel *Panel3;
	TListBox *ListBox1;
	TSpeedButton *SpeedButton1;
	TSpeedButton *SpeedButton2;
	TEdit *NameEdit;
	TEdit *MachineEdit;
	TEdit *DirEdit;
	TPanel *Panel4;
	TSpeedButton *SpeedButton3;
	TSpeedButton *SpeedButton4;
	TLabel *Label1;
	TLabel *Label2;
	TLabel *Label3;
	TCheckBox *CheckBox1;
	void __fastcall FormShow(TObject *Sender);
	void __fastcall FormClose(TObject *Sender, TCloseAction &Action);
	void __fastcall NameEditChange(TObject *Sender);
	void __fastcall SpeedButton4Click(TObject *Sender);
	void __fastcall ListBox1Click(TObject *Sender);
	void __fastcall MachineEditChange(TObject *Sender);
	void __fastcall DirEditChange(TObject *Sender);
	void __fastcall SpeedButton2Click(TObject *Sender);
	void __fastcall SpeedButton1Click(TObject *Sender);
	void __fastcall SpeedButton3Click(TObject *Sender);
private:	// User declarations
	SWConfig *config;
	void checkDisabled();
	
public:		// User declarations
	__fastcall TRemoteMntForm(TComponent* Owner);
};
//---------------------------------------------------------------------------
extern PACKAGE TRemoteMntForm *RemoteMntForm;
//---------------------------------------------------------------------------
#endif

==> sword-1.5.6.tar.gz: sword-1.5.6/apps/windoze/CBuilder5/InstallMgr/RemoteMntFrm.h <==
//---------------------------------------------------------------------------
#ifndef RemoteMntFrmH
#define RemoteMntFrmH
//---------------------------------------------------------------------------
#include <Classes.hpp>
#include <Controls.hpp>
#include <StdCtrls.hpp>
#include <Forms.hpp>
#include <Buttons.hpp>
#include <ExtCtrls.hpp>
#include <swconfig.h>
//---------------------------------------------------------------------------

using namespace sword;

class TRemoteMntForm : public TForm {
__published:	// IDE-managed Components
	TPanel *Panel1;
	TPanel *Panel2;
	TPanel *Panel3;
	TListBox *ListBox1;
	TSpeedButton *SpeedButton1;
	TSpeedButton *SpeedButton2;
	TEdit *NameEdit;
	TEdit *MachineEdit;
	TEdit *DirEdit;
	TPanel *Panel4;
	TSpeedButton *SpeedButton3;
	TSpeedButton *SpeedButton4;
	TLabel *Label1;
	TLabel *Label2;
	TLabel *Label3;
	TCheckBox *CheckBox1;
	void __fastcall FormShow(TObject *Sender);
	void __fastcall FormClose(TObject *Sender, TCloseAction &Action);
	void __fastcall NameEditChange(TObject *Sender);
	void __fastcall SpeedButton4Click(TObject *Sender);
	void __fastcall ListBox1Click(TObject *Sender);
	void __fastcall MachineEditChange(TObject *Sender);
	void __fastcall DirEditChange(TObject *Sender);
	void __fastcall SpeedButton2Click(TObject *Sender);
	void __fastcall SpeedButton1Click(TObject *Sender);
	void __fastcall SpeedButton3Click(TObject *Sender);
private:	// User declarations
	SWConfig *config;
	void checkDisabled();
	
public:		// User declarations
	__fastcall TRemoteMntForm(TComponent* Owner);
};
//---------------------------------------------------------------------------
extern PACKAGE TRemoteMntForm *RemoteMntForm;
//---------------------------------------------------------------------------
#endif
